@@ -14,44 +14,39 @@
   +----------------------------------------------------------------------+
 */
 
-#include "coroutine.h"
-#include "coroutine_c_api.h"
+#include "swoole_coroutine.h"
+#include "swoole_coroutine_c_api.h"
 
-using namespace swoole;
+namespace swoole {
 
-Coroutine* Coroutine::current = nullptr;
+Coroutine *Coroutine::current = nullptr;
 long Coroutine::last_cid = 0;
-std::unordered_map<long, Coroutine*> Coroutine::coroutines;
+std::unordered_map<long, Coroutine *> Coroutine::coroutines;
 uint64_t Coroutine::peak_num = 0;
 
 size_t Coroutine::stack_size = SW_DEFAULT_C_STACK_SIZE;
-sw_coro_on_swap_t Coroutine::on_yield = nullptr;
-sw_coro_on_swap_t Coroutine::on_resume = nullptr;
-sw_coro_on_swap_t Coroutine::on_close = nullptr;
-sw_coro_bailout_t Coroutine::on_bailout = nullptr;
+Coroutine::SwapCallback Coroutine::on_yield = nullptr;
+Coroutine::SwapCallback Coroutine::on_resume = nullptr;
+Coroutine::SwapCallback Coroutine::on_close = nullptr;
+Coroutine::BailoutCallback Coroutine::on_bailout = nullptr;
 
-void Coroutine::yield()
-{
+void Coroutine::yield() {
     SW_ASSERT(current == this || on_bailout != nullptr);
-    state = SW_CORO_WAITING;
-    if (sw_likely(on_yield))
-    {
+    state = STATE_WAITING;
+    if (sw_likely(on_yield)) {
         on_yield(task);
     }
     current = origin;
     ctx.swap_out();
 }
 
-void Coroutine::resume()
-{
+void Coroutine::resume() {
     SW_ASSERT(current != this);
-    if (sw_unlikely(on_bailout))
-    {
+    if (sw_unlikely(on_bailout)) {
         return;
     }
-    state = SW_CORO_RUNNING;
-    if (sw_likely(on_resume))
-    {
+    state = STATE_RUNNING;
+    if (sw_likely(on_resume)) {
         on_resume(task);
     }
     origin = current;
@@ -60,60 +55,54 @@ void Coroutine::resume()
     check_end();
 }
 
-void Coroutine::yield_naked()
-{
+void Coroutine::yield_naked() {
     SW_ASSERT(current == this);
-    state = SW_CORO_WAITING;
+    state = STATE_WAITING;
     current = origin;
     ctx.swap_out();
 }
 
-void Coroutine::resume_naked()
-{
+void Coroutine::resume_naked() {
     SW_ASSERT(current != this);
-    if (sw_unlikely(on_bailout))
-    {
+    if (sw_unlikely(on_bailout)) {
         return;
     }
-    state = SW_CORO_RUNNING;
+    state = STATE_RUNNING;
     origin = current;
     current = this;
     ctx.swap_in();
     check_end();
 }
 
-void Coroutine::close()
-{
+void Coroutine::close() {
     SW_ASSERT(current == this);
-    state = SW_CORO_END;
-    if (on_close)
-    {
+    state = STATE_END;
+    if (on_close) {
         on_close(task);
     }
-#ifdef SW_USE_ASM_CONTEXT
-    swTraceLog(SW_TRACE_CONTEXT, "coroutine#%ld stack memory use less than %ld bytes", get_cid(), ctx.get_stack_usage());
+#if !defined(SW_USE_THREAD_CONTEXT) && defined(SW_CONTEXT_DETECT_STACK_USAGE)
+    swTraceLog(
+        SW_TRACE_CONTEXT, "coroutine#%ld stack memory use less than %ld bytes", get_cid(), ctx.get_stack_usage());
 #endif
     current = origin;
     coroutines.erase(cid);
     delete this;
 }
 
-void Coroutine::print_list()
-{
-    for (auto i = coroutines.begin(); i != coroutines.end(); i++)
-    {
+void Coroutine::print_list() {
+    for (auto i = coroutines.begin(); i != coroutines.end(); i++) {
         const char *state;
-        switch(i->second->state){
-        case SW_CORO_INIT:
+        switch (i->second->state) {
+        case STATE_INIT:
             state = "[INIT]";
             break;
-        case SW_CORO_WAITING:
+        case STATE_WAITING:
             state = "[WAITING]";
             break;
-        case SW_CORO_RUNNING:
+        case STATE_RUNNING:
             state = "[RUNNING]";
             break;
-        case SW_CORO_END:
+        case STATE_END:
             state = "[END]";
             break;
         default:
@@ -124,43 +113,35 @@ void Coroutine::print_list()
     }
 }
 
-void Coroutine::set_on_yield(sw_coro_on_swap_t func)
-{
+void Coroutine::set_on_yield(SwapCallback func) {
     on_yield = func;
 }
 
-void Coroutine::set_on_resume(sw_coro_on_swap_t func)
-{
+void Coroutine::set_on_resume(SwapCallback func) {
     on_resume = func;
 }
 
-void Coroutine::set_on_close(sw_coro_on_swap_t func)
-{
+void Coroutine::set_on_close(SwapCallback func) {
     on_close = func;
 }
 
-void Coroutine::bailout(sw_coro_bailout_t func)
-{
+void Coroutine::bailout(BailoutCallback func) {
     Coroutine *co = current;
-    if (!co)
-    {
+    if (!co) {
         // marks that it can no longer resume any coroutine
-        on_bailout = (sw_coro_bailout_t) -1;
+        on_bailout = (BailoutCallback) -1;
         return;
     }
-    if (!func)
-    {
+    if (!func) {
         swError("bailout without bailout function");
     }
-    if (!co->task)
-    {
+    if (!co->task) {
         // TODO: decoupling
         exit(255);
     }
     on_bailout = func;
     // find the coroutine which is closest to the main
-    while (co->origin)
-    {
+    while (co->origin) {
         co = co->origin;
     }
     // it will jump to main context directly (it also breaks contexts)
@@ -168,55 +149,54 @@ void Coroutine::bailout(sw_coro_bailout_t func)
     // expect that never here
     exit(1);
 }
+namespace coroutine {
+bool run(const coroutine_func_t &fn, void *arg) {
+    if (swoole_event_init(SW_EVENTLOOP_WAIT_EXIT) < 0) {
+        return false;
+    }
+    long cid = Coroutine::create(fn, arg);
+    swoole_event_wait();
+    return cid > 0;
+}
+}  // namespace coroutine
+}  // namespace swoole
 
-uint8_t swoole_coroutine_is_in()
-{
-    return !!Coroutine::get_current();
+uint8_t swoole_coroutine_is_in() {
+    return !!swoole::Coroutine::get_current();
 }
 
-long swoole_coroutine_get_current_id()
-{
-    return Coroutine::get_current_cid();
+long swoole_coroutine_get_current_id() {
+    return swoole::Coroutine::get_current_cid();
 }
 
 /**
  * for gdb
  */
-static std::unordered_map<long, Coroutine*>::iterator _gdb_iterator;
+static std::unordered_map<long, swoole::Coroutine *>::iterator _gdb_iterator;
 
-void swoole_coro_iterator_reset()
-{
-    _gdb_iterator = Coroutine::coroutines.begin();
+void swoole_coro_iterator_reset() {
+    _gdb_iterator = swoole::Coroutine::coroutines.begin();
 }
 
-Coroutine* swoole_coro_iterator_each()
-{
-    if (_gdb_iterator == Coroutine::coroutines.end())
-    {
+swoole::Coroutine *swoole_coro_iterator_each() {
+    if (_gdb_iterator == swoole::Coroutine::coroutines.end()) {
         return nullptr;
-    }
-    else
-    {
-        Coroutine *co = _gdb_iterator->second;
+    } else {
+        swoole::Coroutine *co = _gdb_iterator->second;
         _gdb_iterator++;
         return co;
     }
 }
 
-Coroutine* swoole_coro_get(long cid)
-{
-    auto i = Coroutine::coroutines.find(cid);
-    if (i == Coroutine::coroutines.end())
-    {
+swoole::Coroutine *swoole_coro_get(long cid) {
+    auto i = swoole::Coroutine::coroutines.find(cid);
+    if (i == swoole::Coroutine::coroutines.end()) {
         return nullptr;
-    }
-    else
-    {
+    } else {
         return i->second;
     }
 }
 
-size_t swoole_coro_count()
-{
-    return Coroutine::coroutines.size();
+size_t swoole_coro_count() {
+    return swoole::Coroutine::coroutines.size();
 }
