@@ -1,26 +1,23 @@
-#include "server.h"
-
+#include "swoole_server.h"
 #ifdef SW_SUPPORT_DTLS
 
-namespace swoole { namespace dtls {
+namespace swoole {
+namespace dtls {
 //-------------------------------------------------------------------------------
 
-int BIO_write(BIO *b, const char *data, int dlen)
-{
+int BIO_write(BIO *b, const char *data, int dlen) {
     swTraceLog(SW_TRACE_SSL, "BIO_write(%d)", dlen);
 
     Session *session = (Session *) BIO_get_data(b);
-    return write(session->socket->fd, data, dlen);
+    return session->socket->write(data, dlen);
 }
 
-int BIO_read(BIO *b, char *data, int len)
-{
+int BIO_read(BIO *b, char *data, int len) {
     Session *session = (Session *) BIO_get_data(b);
     Buffer *buffer;
     BIO_clear_retry_flags(b);
 
-    if (!session->rxqueue.empty())
-    {
+    if (!session->rxqueue.empty()) {
         buffer = session->rxqueue.front();
 
         swTrace("BIO_read(%d, peek=%d)=%d", len, session->peek_mode, buffer->length);
@@ -28,41 +25,36 @@ int BIO_read(BIO *b, char *data, int len)
         int n = (buffer->length <= len) ? buffer->length : len;
         memmove(data, buffer->data, n);
 
-        if (!session->peek_mode)
-        {
+        if (!session->peek_mode) {
             session->rxqueue.pop_front();
             sw_free(buffer);
         }
 
         return n;
-    }
-    else
-    {
+    } else {
         BIO_set_retry_read(b);
         return -1;
     }
 }
 
-long BIO_ctrl(BIO *b, int cmd, long lval, void *ptrval)
-{
+long BIO_ctrl(BIO *b, int cmd, long lval, void *ptrval) {
     long retval = 0;
     Session *session = (Session *) BIO_get_data(b);
 
     swTraceLog(SW_TRACE_SSL, "BIO_ctrl(BIO[0x%016lX], cmd[%d], lval[%ld], ptrval[0x%016lX])", b, cmd, lval, ptrval);
 
-    switch (cmd)
-    {
+    switch (cmd) {
     case BIO_CTRL_EOF:
-            return session->rxqueue.empty();
-        case BIO_CTRL_GET_CLOSE:
-            return BIO_get_shutdown(b);
-        case BIO_CTRL_SET_CLOSE:
-            BIO_set_shutdown(b, (int) lval);
-            break;
-        case BIO_CTRL_WPENDING:
-            return 0;
-        case BIO_CTRL_PENDING:
-            return (long) session->get_buffer_length();
+        return session->rxqueue.empty();
+    case BIO_CTRL_GET_CLOSE:
+        return BIO_get_shutdown(b);
+    case BIO_CTRL_SET_CLOSE:
+        BIO_set_shutdown(b, (int) lval);
+        break;
+    case BIO_CTRL_WPENDING:
+        return 0;
+    case BIO_CTRL_PENDING:
+        return (long) session->get_buffer_length();
 
     case BIO_CTRL_FLUSH:
     case BIO_CTRL_DGRAM_SET_CONNECTED:
@@ -70,8 +62,7 @@ long BIO_ctrl(BIO *b, int cmd, long lval, void *ptrval)
         retval = 1;
         break;
     case BIO_CTRL_DGRAM_GET_PEER:
-        if (ptrval)
-        {
+        if (ptrval) {
             memcpy(ptrval, &session->socket->info, sizeof(session->socket->info.addr));
         }
         retval = 1;
@@ -80,13 +71,17 @@ long BIO_ctrl(BIO *b, int cmd, long lval, void *ptrval)
     case BIO_CTRL_DGRAM_GET_FALLBACK_MTU:
         retval = 1500;
         break;
+#ifdef BIO_CTRL_DGRAM_GET_MTU_OVERHEAD
     case BIO_CTRL_DGRAM_GET_MTU_OVERHEAD:
-        retval = 96; // random guess
+        retval = 96;  // random guess
         break;
+#endif
+#ifdef BIO_CTRL_DGRAM_SET_PEEK_MODE
     case BIO_CTRL_DGRAM_SET_PEEK_MODE:
         ((Session *) BIO_get_data(b))->peek_mode = !!lval;
         retval = 1;
         break;
+#endif
     case BIO_CTRL_PUSH:
     case BIO_CTRL_POP:
     case BIO_CTRL_DGRAM_SET_NEXT_TIMEOUT:
@@ -101,13 +96,11 @@ long BIO_ctrl(BIO *b, int cmd, long lval, void *ptrval)
     return retval;
 }
 
-int BIO_create(BIO *b)
-{
+int BIO_create(BIO *b) {
     return 1;
 }
 
-int BIO_destroy(BIO *b)
-{
+int BIO_destroy(BIO *b) {
     swTraceLog(SW_TRACE_SSL, "BIO_destroy(BIO[0x%016lX])\n", b);
     return 1;
 }
@@ -115,10 +108,8 @@ int BIO_destroy(BIO *b)
 static BIO_METHOD *_bio_methods = nullptr;
 static int dtls_session_index = 0;
 
-BIO_METHOD *BIO_get_methods(void)
-{
-    if (_bio_methods)
-    {
+BIO_METHOD *BIO_get_methods(void) {
+    if (_bio_methods) {
         return _bio_methods;
     }
 
@@ -130,37 +121,31 @@ BIO_METHOD *BIO_get_methods(void)
     BIO_meth_set_ctrl(_bio_methods, BIO_ctrl);
     BIO_meth_set_create(_bio_methods, BIO_create);
     BIO_meth_set_destroy(_bio_methods, BIO_destroy);
-    BIO_meth_set_callback_ctrl(_bio_methods, BIO_callback_ctrl);
+    BIO_meth_set_callback_ctrl(_bio_methods, (long (*)(BIO *, int, BIO_info_cb *)) BIO_callback_ctrl);
 
     return _bio_methods;
 }
 
-void BIO_meth_free(void)
-{
-    if (_bio_methods)
-    {
+void BIO_meth_free(void) {
+    if (_bio_methods) {
         BIO_meth_free(_bio_methods);
     }
 
     _bio_methods = nullptr;
 }
 
-void Session::append(const char* data, ssize_t len)
-{
+void Session::append(const char *data, ssize_t len) {
     Buffer *buffer = (Buffer *) sw_malloc(sizeof(*buffer) + len);
     buffer->length = len;
     memcpy(buffer->data, data, buffer->length);
     rxqueue.push_back(buffer);
 }
 
-bool Session::init()
-{
-    if (socket->ssl)
-    {
+bool Session::init() {
+    if (socket->ssl) {
         return false;
     }
-    if (swSSL_create(socket, ctx, SW_SSL_SERVER) < 0)
-    {
+    if (socket->ssl_create(ctx, SW_SSL_SERVER) < 0) {
         return false;
     }
     socket->dtls = 1;
@@ -173,33 +158,25 @@ bool Session::init()
     return true;
 }
 
-bool Session::listen()
-{
-    if (listened)
-    {
+bool Session::listen() {
+    if (listened) {
         return false;
     }
 
     ERR_clear_error();
 
-    int retval = DTLSv1_listen(socket->ssl, NULL);
-    if (retval == 0)
-    {
+    int retval = DTLSv1_listen(socket->ssl, nullptr);
+    if (retval == 0) {
         return true;
-    }
-    else if (retval < 0)
-    {
+    } else if (retval < 0) {
         int reason = ERR_GET_REASON(ERR_peek_error());
-        swWarn(
-            "DTLSv1_listen() failed, client[%s:%d], reason=%d, error_string=%s",
-            swSocket_get_ip(socket->socket_type, &socket->info),
-            swSocket_get_port(socket->socket_type, &socket->info),
-            reason, swSSL_get_error()
-        );
+        swWarn("DTLSv1_listen() failed, client[%s:%d], reason=%d, error_string=%s",
+               socket->info.get_ip(),
+               socket->info.get_port(),
+               reason,
+               swSSL_get_error());
         return false;
-    }
-    else
-    {
+    } else {
         listened = true;
     }
 
@@ -207,6 +184,7 @@ bool Session::listen()
 }
 
 //-------------------------------------------------------------------------------
-}}
+}  // namespace dtls
+}  // namespace swoole
 
 #endif
