@@ -15,112 +15,95 @@
 */
 
 #include "swoole_api.h"
-#include "wrapper/base.hpp"
-#include "server.h"
+#include "swoole_timer.h"
 
-using namespace std;
 using namespace swoole;
 
 #ifdef __MACH__
-swTimer* sw_timer()
-{
+Timer *sw_timer() {
     return SwooleTG.timer;
 }
 #endif
 
-swTimer_node* swoole_timer_add(long ms, uchar persistent, swTimerCallback callback, void *private_data)
-{
-    if (sw_unlikely(SwooleTG.timer == nullptr))
-    {
-        SwooleTG.timer = (swTimer *) sw_malloc(sizeof(swTimer));
-        if (sw_unlikely(SwooleTG.timer == nullptr))
-        {
-            return nullptr;
-        }
-        if (sw_unlikely(swTimer_init(SwooleTG.timer, ms) != SW_OK))
-        {
-            sw_free(SwooleTG.timer);
+TimerNode *swoole_timer_add(long ms, bool persistent, const TimerCallback &callback, void *private_data) {
+    if (sw_unlikely(SwooleTG.timer == nullptr)) {
+        SwooleTG.timer = new Timer();
+        if (sw_unlikely(!SwooleTG.timer->init())) {
+            delete SwooleTG.timer;
             SwooleTG.timer = nullptr;
             return nullptr;
         }
     }
-    return swTimer_add(SwooleTG.timer, ms, persistent, private_data, callback);
+    return SwooleTG.timer->add(ms, persistent, private_data, callback);
 }
 
-uchar swoole_timer_del(swTimer_node* tnode)
-{
-    return swTimer_del(SwooleTG.timer, tnode);
+bool swoole_timer_del(TimerNode *tnode) {
+    return SwooleTG.timer->remove(tnode);
 }
 
-long swoole_timer_after(long ms, swTimerCallback callback, void *private_data)
-{
-    if (ms <= 0)
-    {
+void swoole_timer_delay(TimerNode *tnode, long delay_ms) {
+    return SwooleTG.timer->delay(tnode, delay_ms);
+}
+
+long swoole_timer_after(long ms, const TimerCallback &callback, void *private_data) {
+    if (ms <= 0) {
         swWarn("Timer must be greater than 0");
         return SW_ERR;
     }
-    swTimer_node *tnode = swoole_timer_add(ms, SW_FALSE, callback, private_data);
-    if (tnode == nullptr)
-    {
+    TimerNode *tnode = swoole_timer_add(ms, false, callback, private_data);
+    if (tnode == nullptr) {
         return SW_ERR;
-    }
-    else
-    {
+    } else {
         return tnode->id;
     }
 }
 
-long swoole_timer_tick(long ms, swTimerCallback callback, void *private_data)
-{
-    if (ms <= 0)
-    {
+long swoole_timer_tick(long ms, const TimerCallback &callback, void *private_data) {
+    if (ms <= 0) {
         swWarn("Timer must be greater than 0");
         return SW_ERR;
     }
-    swTimer_node *tnode = swoole_timer_add(ms, SW_TRUE, callback, private_data);
-    if (tnode == nullptr)
-    {
+    TimerNode *tnode = swoole_timer_add(ms, true, callback, private_data);
+    if (tnode == nullptr) {
         return SW_ERR;
-    }
-    else
-    {
+    } else {
         return tnode->id;
     }
 }
 
-uchar swoole_timer_exists(long timer_id)
-{
-    if (!SwooleTG.timer)
-    {
+bool swoole_timer_exists(long timer_id) {
+    if (!SwooleTG.timer) {
         swWarn("no timer");
         return false;
     }
-    swTimer_node *tnode = swTimer_get(SwooleTG.timer, timer_id);
+    TimerNode *tnode = SwooleTG.timer->get(timer_id);
     return (tnode && !tnode->removed);
 }
 
-uchar swoole_timer_clear(long timer_id)
-{
-    return swTimer_del(SwooleTG.timer, swTimer_get(SwooleTG.timer, timer_id));
+bool swoole_timer_clear(long timer_id) {
+    return SwooleTG.timer->remove(SwooleTG.timer->get(timer_id));
 }
 
-swTimer_node* swoole_timer_get(long timer_id)
-{
-    if (!SwooleTG.timer)
-    {
+TimerNode *swoole_timer_get(long timer_id) {
+    if (!SwooleTG.timer) {
         swWarn("no timer");
         return nullptr;
     }
-    return swTimer_get(SwooleTG.timer, timer_id);
+    return SwooleTG.timer->get(timer_id);
 }
 
-void swoole_timer_free()
-{
-    if (!SwooleTG.timer)
-    {
+void swoole_timer_free() {
+    if (!SwooleTG.timer) {
         return;
     }
-    swTimer_free(SwooleTG.timer);
-    sw_free(SwooleTG.timer);
+    delete SwooleTG.timer;
     SwooleTG.timer = nullptr;
+    SwooleG.signal_alarm = false;
+}
+
+int swoole_timer_select() {
+    if (!SwooleTG.timer) {
+        return SW_ERR;
+    }
+    return SwooleTG.timer->select();
 }
