@@ -17,11 +17,13 @@ define('USE_VALGRIND', getenv('USE_ZEND_ALLOC') === '0');
 define('HAS_SSL', defined("SWOOLE_SSL"));
 define('HAS_ASYNC_REDIS', class_exists("swoole_redis", false));
 define('HAS_HTTP2', class_exists("swoole_http2_request", false));
+define('DEV_NULL', '/dev/null');
 
 /** ============== Files ============== */
 define('SOURCE_ROOT_PATH', __DIR__ . '/../../');
 define('TRAVIS_DIR_PATH', __DIR__ . '/../../travis/');
 define('TEST_IMAGE', __DIR__ . '/../../examples/test.jpg');
+define('TEST_LINK_IMAGE', __DIR__ . '/../../examples/test_link.jpg');
 define('TEST_IMAGE2', __DIR__ . '/../../examples/logo.svg');
 define('TEST_LOG_FILE', '/tmp/swoole.log');
 define('TEST_PID_FILE', '/tmp/swoole.pid');
@@ -88,16 +90,17 @@ if (IS_IN_TRAVIS) {
 define('IP_REGEX', '/^(?:[\d]{1,3}\.){3}[\d]{1,3}$/');
 
 /** ============= Proxy ============== */
-define('HTTP_PROXY_HOST', '127.0.0.1');
-define('HTTP_PROXY_PORT', IS_MAC_OS ? 1087 : 8888);
-define('SOCKS5_PROXY_HOST', '127.0.0.1');
+define('HTTP_PROXY_HOST', IS_IN_TRAVIS ? 'tinyproxy' : '127.0.0.1');
+define('HTTP_PROXY_PORT', IS_IN_TRAVIS ? 8888 : (IS_MAC_OS ? 1087 : 8888));
+define('SOCKS5_PROXY_HOST', IS_IN_TRAVIS ? 'socks5' : '127.0.0.1');
 define('SOCKS5_PROXY_PORT', IS_MAC_OS ? 1086 : 1080);
 
 /** ============== Pressure ============== */
 define('PRESSURE_LOW', 1);
 define('PRESSURE_MID', 2);
 define('PRESSURE_NORMAL', 3);
-define('PRESSURE_LEVEL', USE_VALGRIND ? PRESSURE_LOW : ((IS_IN_TRAVIS || swoole_cpu_num() === 1) ? PRESSURE_MID : PRESSURE_NORMAL));
+define('PRESSURE_LEVEL',
+    USE_VALGRIND ? (IS_IN_TRAVIS ? PRESSURE_LOW - 1 : PRESSURE_LOW) : ((IS_IN_TRAVIS || swoole_cpu_num() === 1) ? PRESSURE_MID : PRESSURE_NORMAL));
 
 /** ============== Time ============== */
 define('SERVER_PREHEATING_TIME', 0.1);
@@ -112,3 +115,4 @@ define('MAX_REQUESTS_MID', [8, 16, 32, 64][PRESSURE_LEVEL]);
 define('MAX_REQUESTS_LOW', [4, 8, 10, 25][PRESSURE_LEVEL]);
 define('MAX_LOOPS', [12, 24, 100, 1000][PRESSURE_LEVEL] * 1000);
 define('MAX_PROCESS_NUM', [2, 4, 6, 8][PRESSURE_LEVEL]);
+define('MAX_PACKET_NUM', [1024, 2048, 4096, 10000][PRESSURE_LEVEL]);
