@@ -54,7 +54,7 @@
 #include "net.h"
 #include "sds.h"
 
-#include "socket_hook.h"
+#include "swoole_socket_hook.h"
 
 /* Defined in hiredis.c */
 void __redisSetError(redisContext *c, int type, const char *str);
@@ -103,8 +103,7 @@ static int redisCreateSocket(redisContext *c, int type) {
 }
 
 static int redisSetBlocking(redisContext *c, int blocking) {
-
-    return REDIS_OK;
+#if 0
     int flags;
 
     /* Set the socket nonblocking.
@@ -126,6 +125,7 @@ static int redisSetBlocking(redisContext *c, int blocking) {
         redisContextCloseFd(c);
         return REDIS_ERR;
     }
+#endif
     return REDIS_OK;
 }
 
