@@ -2,7 +2,7 @@
 <?php
 require __DIR__ . '/bootstrap.php';
 
-define('LIBRARY_HEADER', ROOT_DIR . '/php_swoole_library.h');
+define('LIBRARY_HEADER', ROOT_DIR . '/ext-src/php_swoole_library.h');
 define('PHP_TAG', '<?php');
 
 preg_match(
@@ -29,11 +29,13 @@ $files = [
     'core/Constant.php',
     'core/StringObject.php',
     'core/MultibyteStringObject.php',
+    'core/Exception/ArrayKeyNotExists.php',
     'core/ArrayObject.php',
     'core/ObjectProxy.php',
     'core/Coroutine/WaitGroup.php',
     'core/Coroutine/Server.php',
     'core/Coroutine/Server/Connection.php',
+    'core/Coroutine/Barrier.php',
     # <core for connection pool> #
     'core/ConnectionPool.php',
     'core/Database/ObjectProxy.php',
@@ -76,6 +78,10 @@ $files = [
     'core/Coroutine/FastCGI/Client.php',
     'core/Coroutine/FastCGI/Client/Exception.php',
     'core/Coroutine/FastCGI/Proxy.php',
+    # <core for Process> #
+    'core/Process/Manager.php',
+    # <core for Server> #
+    'core/Server/Helper.php',
     # <core for functions> #
     'core/Coroutine/functions.php',
     # <ext> #
@@ -86,6 +92,11 @@ $files = [
     'alias_ns.php',
 ];
 
+$diff_files = array_diff(swoole_library_files(), $files);
+if (!empty($diff_files)) {
+    swoole_error('Some files are not loaded: ', ...$diff_files);
+}
+
 foreach ($files as $file) {
     if (!file_exists(LIBRARY_SRC_DIR . '/' . $file)) {
         swoole_error("Unable to find source file [{$file}]");
